@@ -68,4 +68,24 @@ class DBConnectionUndefined(JarvisException):
     pass
 
 class ClientException(JarvisException):
-    pass
\ No newline at end of file
+    pass
+
+class ModelException(JarvisException):
+    pass
+
+class CommandException(ModelException):
+    pass
+
+class CommandNotFoundException(CommandException):
+    pass
+
+class CommandNotCreatedException(CommandException):
+    pass
+
+class CommandNotDeletedException(CommandException):
+    pass
+
+class CommandNotDeletedException(CommandException):
+    pass
+
+
